# echo360download

This is modified version of script written by Andrew Ferguson: https://tardis.ed.ac.uk/~andrewferguson/echo360/

# Install

``pip3 install echo360download``

# Usage:

Example
``
$ echo360download Downloads/ cookies.txt
``

this will prompt you with available list and you can choose which one to download.